--[[

ARLFrame.lua

Frame functions for all of AckisRecipeList

]]--

local L			= LibStub("AceLocale-3.0"):GetLocale("AckisRecipeList")
local Crayon	= LibStub("LibCrayon-3.0")
ARL = AckisRecipeList

-- Calculates the total height of all the recipes in the child frame

local function ARL_CalculateChildHeight()

	local tempheight = 0
	RecipeFrame = AckisRecipeListRecipe1

	while (RecipeFrame ~= nil) do
		tempheight = RecipeFrame:GetHeight() + RecipeFrame.RecipeAquireText:GetHeight() + tempheight
		RecipeFrame = RecipeFrame.NextRecipe
	end

	return tempheight

end

-- Adds recipe text info to the frames
-- Function to run when the + is clicked in the frame.  Will expand the recipe name and print out how to obtain it.

local function ARL_OnClickExpandRecipe()

	if (this.IsPushed == false) then
		local RecipeText = nil 

		if (AckisRecipeList.db.profile.sorting == "Skill") then
			RecipeText = string.match(this:GetText(), "%[.*%] %- (.*)")
		elseif (AckisRecipeList.db.profile.sorting == "Name") then
			RecipeText = string.match(this:GetText(), "(.*) %- %[.*%]")
		end

		-- Changed the graphic of the + to a -
		this:SetNormalTexture("Interface\\Buttons\\UI-MinusButton-Up")
		this:SetPushedTexture("Interface\\Buttons\\UI-MinusButton-Down")
		this:SetHighlightTexture("Interface\\Buttons\\UI-MinusButton-Hilight")

		-- Keep track of button state
		this.IsPushed = true

		-- Show expanded text
		if (ARL.MissingRecipeListing[RecipeText]["Acquire"] == nil) then
			this.RecipeAquireText:SetText(L["NoObtain"])
		else
			this.RecipeAquireText:SetText("    - " .. ARL.MissingRecipeListing[RecipeText]["Acquire"])
		end

		this.RecipeAquireText:Show()

		-- Reposition the next recipe entry
		if (this.NextRecipe ~= nil) then
			this.NextRecipe:ClearAllPoints()
			this.NextRecipe:SetPoint("TOPLEFT", this.RecipeAquireText, "BOTTOMLEFT", -20, -5)
		end

	else

		-- Changed the graphic of the - to a +
		this:SetNormalTexture("Interface\\Buttons\\UI-PlusButton-Up")
		this:SetPushedTexture("Interface\\Buttons\\UI-PlusButton-Down")
		this:SetHighlightTexture("Interface\\Buttons\\UI-PlusButton-Hilight")

		-- Keep track of button state
		this.IsPushed = false

		-- Hide expanded text
		this.RecipeAquireText:SetText("")
		this.RecipeAquireText:Hide()

		-- Reposition the next recipe entry
		if (this.NextRecipe ~= nil) then
			this.NextRecipe:ClearAllPoints()
			this.NextRecipe:SetPoint("TOPLEFT", this, "BOTTOMLEFT", 0, 0)
		end
	end

	AckisRecipeListFrameScrollFrame:UpdateScrollChildRect()

	-- Show the scroll bar or not
	if (ARL_CalculateChildHeight() < 355) then
		this.RecipeAquireText:SetWidth(320)
		AckisRecipeListFrameScrollFrameScrollBar:Hide()
	else
		this.RecipeAquireText:SetWidth(310)
		AckisRecipeListFrameScrollFrameScrollBar:Show()
	end

end

-- Adds recipe text info to the frames

local function ARL_AddRecipeInfo(CurrentProfession, CurrentProfessionLevel, SortedList, CurrentSpeciality)

	local OldFrame = nil
	local RecipeFrame = nil
	local RecipeCount = 1
	
	for i, RecipeName in ipairs(SortedList) do

		if (AckisRecipeList:CheckDisplayRecipe(RecipeName, CurrentProfessionLevel, CurrentProfession, CurrentSpeciality)) then

			-- If the frame isn't created, then create it and set the parameters for it, otherwise use the current frame (recycle it)
			if (not _G["AckisRecipeListRecipe" .. RecipeCount]) then
				RecipeFrame = CreateFrame("Button", "AckisRecipeListRecipe" .. RecipeCount, AckisRecipeListFrameScrollChild, "ClassTrainerSkillButtonTemplate")
				RecipeFrame:SetNormalTexture("Interface\\Buttons\\UI-PlusButton-Up")
				RecipeFrame:SetPushedTexture("Interface\\Buttons\\UI-PlusButton-Down")
				RecipeFrame:SetHighlightTexture("Interface\\Buttons\\UI-PlusButton-Hilight")
				RecipeFrame:SetTextColor(1, 1, 1)
				RecipeFrame:SetWidth(18)
				RecipeFrame:SetScript("OnClick", ARL_OnClickExpandRecipe)
				RecipeFrame.IsPushed = false

				-- Create aquire text for the recipe
				RecipeFrame.RecipeAquireText = RecipeFrame:CreateFontString("AckisRecipeListRecipe" .. RecipeCount .. "Text", "DIALOG")

				RecipeFrame.RecipeAquireText:ClearAllPoints()
				RecipeFrame.RecipeAquireText:SetPoint("TOPLEFT", RecipeFrame, "BOTTOMLEFT", 20, 0)
				RecipeFrame.RecipeAquireText:SetFontObject("GameFontNormalSmall")
				RecipeFrame.RecipeAquireText:SetTextColor(1, 1, 1)
				RecipeFrame.RecipeAquireText:SetJustifyH("LEFT")

			else

				-- Grab the frame from the global stack
				RecipeFrame = _G["AckisRecipeListRecipe" .. RecipeCount]

			end

			-- If we have a previous recipe, set the previous recipe next recipe to this current recipe
			if (OldFrame ~= nil) then
				OldFrame.NextRecipe = RecipeFrame
			end

			-- If we're at the last recipe, set the next reicpe to nil, otherwise set the previous entries nextrecipe to a temp variable.
			local NumMissingRecipes = ARL.NumberOfRecipes - ARL.FoundRecipes
			if (i == NumMissingRecipes) then
				RecipeFrame.NextRecipe = nil
			else
				OldFrame = RecipeFrame
			end

			RecipeFrame:ClearAllPoints()

			-- If we're on the first recipe, set the points in relation to the main frame, otherwise set them in relation to the previous recipe
			if (RecipeCount == 1) then
				RecipeFrame:SetPoint("TOPLEFT", AckisRecipeListFrameScrollChild, "TOPLEFT", 5, -30)
			else
				RecipeFrame:SetPoint("TOPLEFT", "AckisRecipeListRecipe" .. (RecipeCount - 1), "BOTTOMLEFT", 0, -1)
			end

			if (AckisRecipeList.db.profile.sorting == "Skill") then
				if (ARL.MissingRecipeListing[RecipeName]["Level"] > CurrentProfessionLevel) then
					RecipeFrame:SetText(Crayon:Red("[" .. ARL.MissingRecipeListing[RecipeName]["Level"] .. "]") .. " - " .. RecipeName)
				else
					RecipeFrame:SetText("[" .. ARL.MissingRecipeListing[RecipeName]["Level"] .. "] - " .. RecipeName)
				end
			elseif (AckisRecipeList.db.profile.sorting == "Name") then
				if (ARL.MissingRecipeListing[RecipeName]["Level"] > CurrentProfessionLevel) then
					RecipeFrame:SetText(RecipeName .. " - " .. Crayon:Red("[" .. ARL.MissingRecipeListing[RecipeName]["Level"] .. "]"))
				else
					RecipeFrame:SetText(RecipeName .. " - [" .. ARL.MissingRecipeListing[RecipeName]["Level"] .. "]")
				end
			end

			RecipeFrame:Show()
			RecipeCount = RecipeCount + 1
		end

	end

	-- Show the scroll bar or not
	if (ARL_CalculateChildHeight() < 355) then
		AckisRecipeListFrameScrollFrameScrollBar:Hide()
	else
		AckisRecipeListFrameScrollFrameScrollBar:Show()
	end

end

-- Closes the frame and cleans sets everything that was displayed to nil

function ARL:CloseWindow()

	-- Clean up recipe entries
	local RecipeFrame = AckisRecipeListRecipe1

	-- Clear x number of entries for all missing recipes
	while (RecipeFrame ~= nil) do
		--RecipeFrame.RecipeAquireText:ClearAllPoints()
		RecipeFrame.RecipeAquireText:SetText("")
		RecipeFrame.RecipeAquireText:Hide()

		RecipeFrame:SetText("")
		RecipeFrame:Hide()

		if (RecipeFrame.IsPushed == true) then
			RecipeFrame:SetNormalTexture("Interface\\Buttons\\UI-PlusButton-Up")
			RecipeFrame:SetPushedTexture("Interface\\Buttons\\UI-PlusButton-Down")
			RecipeFrame:SetDisabledTexture("Interface\\Buttons\\UI-PlusButton-Disabled")
			RecipeFrame:SetHighlightTexture("Interface\\Buttons\\UI-PlusButton-Hilight")
			RecipeFrame.IsPushed = false
		end

		RecipeFrame.RecipeAquireText:SetText("")
		RecipeFrame.RecipeAquireText:Hide()
		RecipeFrame = RecipeFrame.NextRecipe
	end

	AckisRecipeListFrame:Hide()

	ARL.ResetOkayARL = true

	if (ARL_ResetOkayBlizz and ARL.ResetOkayARL) then
		ARL:ARL_ResetVariables()
	end

end

-- Expands all the headers

function ARL:ExpandAll()

	local frame = _G["AckisRecipeListRecipe1"]

	if (frame) then
		if (frame.IsPushed == false) then
			frame:ARL_OnClickExpandRecipe()
		end
	end

end

-- Closes all the headers

function ARL:CloseAll()

end

-- Create the scan button and add it to Skillet if applicable

function ARL:CreateScanButton()
	if (not AckisRecipeListFrameScanButton) then
		AckisRecipeListFrameScanButton = CreateFrame("Button","AckisRecipeListFrameScanButton",UIParent,"UIPanelButtonTemplate")
	end
	-- Add to Skillet interface
	if (Skillet and Skillet:IsActive() and not CraftIsPetTraining()) then
		AckisRecipeListFrameScanButton:SetParent(SkilletFrame)
		AckisRecipeListFrameScanButton:Show()
		AckisRecipeListFrameScanButton:SetTextColor(1, 0.8, 0)
		Skillet:AddButtonToTradeskillWindow(AckisRecipeListFrameScanButton)
		AckisRecipeListFrameScanButton:SetWidth(80)
		AckisRecipeListFrameScanButton:SetHeight(24)
		AckisRecipeListFrameScanButton:RegisterForClicks("LeftButtonUp")
		AckisRecipeListFrameScanButton:SetScript("OnClick", function() ARL:ToggleFrame() end)
		AckisRecipeListFrameScanButton:SetText(L["ARLScanButton"])
		AckisRecipeListFrameScanButton:Enable()
	end
end


-- Adds a button to the trade skill/skillet/crafting skill window allowing you to scan

function ARL:AddScanButton()
	-- Add to ATSW
	if (ATSWFrame and not CraftIsPetTraining()) then
		AckisRecipeListFrameScanButton:SetParent(ATSWFrame)
		AckisRecipeListFrameScanButton:Show()
		AckisRecipeListFrameScanButton:ClearAllPoints()
		AckisRecipeListFrameScanButton:SetPoint("RIGHT", ATSWOptionsButton, "LEFT", 0, 0)
		AckisRecipeListFrameScanButton:SetTextColor(ATSWOptionsButton:GetTextColor())
		AckisRecipeListFrameScanButton:SetHeight(ATSWOptionsButton:GetHeight())
		AckisRecipeListFrameScanButton:SetWidth(80)
	elseif (ARL.SkillType == "Trade") then
	-- Anchor to trade window
		AckisRecipeListFrameScanButton:SetParent(TradeSkillFrame)
		AckisRecipeListFrameScanButton:Show()
		AckisRecipeListFrameScanButton:ClearAllPoints()
		AckisRecipeListFrameScanButton:SetPoint("CENTER",TradeSkillFrameCloseButton,"LEFT",-15,0)
		AckisRecipeListFrameScanButton:SetTextColor(1, 1, 0)
		AckisRecipeListFrameScanButton:SetWidth(40)
	-- Anchor to crafting window
	elseif (ARL.SkillType == "Craft") then
		AckisRecipeListFrameScanButton:SetParent(CraftFrame)
		AckisRecipeListFrameScanButton:Show()
		AckisRecipeListFrameScanButton:ClearAllPoints()
		AckisRecipeListFrameScanButton:SetPoint("CENTER",CraftFrameCloseButton,"LEFT",-15,0)
		AckisRecipeListFrameScanButton:SetTextColor(1, 1, 0)
		AckisRecipeListFrameScanButton:SetWidth(40)
	end

	AckisRecipeListFrameScanButton:SetHeight(24)
	AckisRecipeListFrameScanButton:RegisterForClicks("LeftButtonUp")
	AckisRecipeListFrameScanButton:SetScript("OnClick", function() ARL:ToggleFrame() end)
	AckisRecipeListFrameScanButton:SetText(L["ARLScanButton"])
	AckisRecipeListFrameScanButton:Enable()
	AckisRecipeListFrameScanButton:Show()
end

-- Allows the scan button to close the scan window

function ARL:ToggleFrame()
	if (AckisRecipeListFrame and AckisRecipeListFrame:IsVisible()) then
		AckisRecipeListFrame:Hide()
	else
		AckisRecipeList:AckisRecipeList_Command()
	end
end

-- Creates the initial frame to display recipes into

function ARL:AckisRecipeList_CreateFrame(CurrentProfession, CurrentProfessionLevel, SortedRecipeIndex, CurrentSpeciality)

	ARL.ResetOkayARL = false

	if (not AckisRecipeListFrame) then

		-- Create the main frame
		AckisRecipeListFrame = CreateFrame("Frame", "AckisRecipeListFrame", UIParent)

		AckisRecipeListFrame:SetWidth(384)
		AckisRecipeListFrame:SetHeight(430)
		AckisRecipeListFrame:SetBackdrop(
		{
			bgFile = "Interface\\DialogFrame\\UI-DialogBox-Background",
			edgeFile = "Interface\\DialogFrame\\UI-DialogBox-Border",
			tile="false",
			edgeSize = 16,
			insets = {
						left = 5,
						right = 5,
						top = 5,
						bottom = 5
					}
		})
		AckisRecipeListFrame:SetBackdropColor(0, 0, 0)
		AckisRecipeListFrame:EnableMouse(true)
		AckisRecipeListFrame:EnableKeyboard(true)
		AckisRecipeListFrame:SetMovable(true)
		AckisRecipeListFrame:SetScript("OnMouseDown", function() AckisRecipeListFrame:StartMoving() end)
		AckisRecipeListFrame:SetScript("OnHide", function() ARL:CloseWindow() end)
		AckisRecipeListFrame:SetScript("OnMouseUp", function() AckisRecipeListFrame:StopMovingOrSizing() end)

		-- Add header frame
		AckisRecipeListFrameHeaderFrame = CreateFrame("Frame", "AckisRecipeListFrameHeaderFrame", AckisRecipeListFrame)

		AckisRecipeListFrameHeaderFrame:SetWidth(192)
		AckisRecipeListFrameHeaderFrame:SetHeight(32)
		AckisRecipeListFrameHeaderFrame:ClearAllPoints()
		AckisRecipeListFrameHeaderFrame:SetPoint("TOP", AckisRecipeListFrame, "TOP", 0, 6)
		AckisRecipeListFrameHeaderFrame:EnableMouse(true)
		AckisRecipeListFrameHeaderFrame:SetMovable(true)
		AckisRecipeListFrameHeaderFrame:SetScript("OnMouseDown", function()	AckisRecipeListFrame:StartMoving()	end)
		AckisRecipeListFrameHeaderFrame:SetScript("OnMouseUp", function() AckisRecipeListFrame:StopMovingOrSizing() end)

		-- Add texture to the header frame
		AckisRecipeListFrameHeaderFrameTexture = AckisRecipeListFrameHeaderFrame:CreateTexture("AckisRecipeListFrameHeaderFrameTexture", "ARTWORK")

		AckisRecipeListFrameHeaderFrameTexture:SetTexture("Interface\\DialogFrame\\UI-DialogBox-Header")
		AckisRecipeListFrameHeaderFrameTexture:SetWidth(384)
		AckisRecipeListFrameHeaderFrameTexture:SetHeight(64)
		AckisRecipeListFrameHeaderFrameTexture:ClearAllPoints()
		AckisRecipeListFrameHeaderFrameTexture:SetPoint("TOP", AckisRecipeListFrameHeaderFrame, "TOP", 0, 5)

		-- Add text to header frame
		AckisRecipeListFrameHeaderFrameText = AckisRecipeListFrameHeaderFrame:CreateFontString("AckisRecipeListFrameHeaderFrameText", "ARTWORK")

		AckisRecipeListFrameHeaderFrameText:SetFontObject(GameFontNormal)
		AckisRecipeListFrameHeaderFrameText:ClearAllPoints()
		AckisRecipeListFrameHeaderFrameText:SetPoint("CENTER", AckisRecipeListFrameHeaderFrame, "CENTER", 0, 0)
		AckisRecipeListFrameHeaderFrameText:SetText(ARL.ARLTitle)

		-- Add close button
		AckisRecipeListFrameCloseButton = CreateFrame("Button", "AckisRecipeListFrameCloseButton", AckisRecipeListFrame, "UIPanelButtonTemplate")

		AckisRecipeListFrameCloseButton:SetWidth(100)
		AckisRecipeListFrameCloseButton:SetHeight(24)
		AckisRecipeListFrameCloseButton:ClearAllPoints()
		AckisRecipeListFrameCloseButton:SetPoint("BOTTOMRIGHT", AckisRecipeListFrame, -10, 10)
		AckisRecipeListFrameCloseButton:RegisterForClicks("LeftButtonUp")
		AckisRecipeListFrameCloseButton:SetScript("OnClick", function() ARL:CloseWindow() end)
		AckisRecipeListFrameCloseButton:SetFont("GameFontHighlightSmall",12)
		AckisRecipeListFrameCloseButton:Enable()
		AckisRecipeListFrameCloseButton:SetTextColor(1, 1, 1)
		AckisRecipeListFrameCloseButton:SetText(L["Close"])

		-- Add a "close with x" button
		AckisRecipeListFrameXButton = CreateFrame("Button", "AckisRecipeListFrameXButton", AckisRecipeListFrame, "UIPanelCloseButton")

		AckisRecipeListFrameXButton:ClearAllPoints()
		AckisRecipeListFrameXButton:SetPoint("TOPRIGHT", AckisRecipeListFrame, "TOPRIGHT", 0, 0)
		AckisRecipeListFrameXButton:RegisterForClicks("LeftButtonUp")
		AckisRecipeListFrameXButton:SetScript("OnClick", function() ARL:CloseWindow() end)
		AckisRecipeListFrameXButton:Enable()

		-- Adds scroll frame to mainframe
		AckisRecipeListFrameScrollFrame = CreateFrame("ScrollFrame", "AckisRecipeListFrameScrollFrame", AckisRecipeListFrame, "UIPanelScrollFrameTemplate")
	
		AckisRecipeListFrameScrollFrame:ClearAllPoints()
		AckisRecipeListFrameScrollFrame:SetPoint("TOPLEFT", AckisRecipeListFrame, "TOPLEFT", 10, -30)
		AckisRecipeListFrameScrollFrame:SetHeight(360)
		AckisRecipeListFrameScrollFrame:SetWidth(344)
		AckisRecipeListFrameScrollFrame:EnableMouseWheel(true)
		AckisRecipeListFrameScrollFrame:EnableMouse(true)

		AckisRecipeListFrameScrollChild = CreateFrame("Frame", "AckisRecipeListFrameScrollChild", AckisRecipeListFrameScrollFrame)

		AckisRecipeListFrameScrollChild:ClearAllPoints()
		AckisRecipeListFrameScrollChild:SetPoint("TOPLEFT", AckisRecipeListScrollFrame, "TOPLEFT", 10, -30)
		AckisRecipeListFrameScrollChild:SetWidth(340)
		AckisRecipeListFrameScrollChild:SetHeight(355)
		AckisRecipeListFrameScrollChild:EnableMouseWheel(true)
		AckisRecipeListFrameScrollChild:EnableMouse(true)

		AckisRecipeListFrameScrollFrame:SetScrollChild(AckisRecipeListFrameScrollChild)

		-- Add progress bar to frame
		AckisRecipeListFrameProgressBar = CreateFrame("StatusBar", "AckisRecipeListFrameProgressBar", AckisRecipeListFrame)
		
		AckisRecipeListFrameProgressBar:SetWidth(260)
		AckisRecipeListFrameProgressBar:SetHeight(20)
		AckisRecipeListFrameProgressBar:ClearAllPoints()
		AckisRecipeListFrameProgressBar:SetPoint("BOTTOMLEFT", AckisRecipeListFrame, 10, 10)
		AckisRecipeListFrameProgressBar:SetStatusBarTexture("Interface\\PaperDollInfoFrame\\UI-Character-Skills-Bar")
		AckisRecipeListFrameProgressBar:SetOrientation("HORIZONTAL")
		AckisRecipeListFrameProgressBar:SetStatusBarColor(0.25, 0.25, 0.75)

		AckisRecipeListFrameProgressBarBorder = CreateFrame("Button", "AckisRecipeListFrameProgressBarBorder", AckisRecipeListFrameProgressBar)

		-- Add border to status bar
		AckisRecipeListFrameProgressBarBorder:SetNormalTexture("Interface\\PaperDollInfoFrame\\UI-Character-Skills-BarBorder")
		AckisRecipeListFrameProgressBarBorder:SetWidth(270)
		AckisRecipeListFrameProgressBarBorder:SetHeight(40)
		AckisRecipeListFrameProgressBarBorder:ClearAllPoints()
		AckisRecipeListFrameProgressBarBorder:SetPoint("CENTER", AckisRecipeListFrameProgressBar, "CENTER", 0, 0)

		AckisRecipeListFrameProgressBarText = AckisRecipeListFrameProgressBar:CreateFontString("AckisRecipeListFrameProgressBarText", "ARTWORK")

		-- Add text to header frame
		AckisRecipeListFrameProgressBarText:SetFontObject(GameFontHighlightSmall)
		AckisRecipeListFrameProgressBarText:ClearAllPoints()
		AckisRecipeListFrameProgressBarText:SetPoint("CENTER", AckisRecipeListFrameProgressBar, "CENTER", 0, 0)

		-- Adds Profession header text
		ARLProfessionText = AckisRecipeListFrameScrollChild:CreateFontString(nil, "ARTWORK", "GameFontNormal")
		ARLProfessionText:SetTextColor(1.0, 1.0, 0.1)
		ARLProfessionText:ClearAllPoints()
		ARLProfessionText:SetPoint("TOP", 0, 0)

	end

	AckisRecipeListFrame:ClearAllPoints()

	-- Anchor the frame to a specific window

	-- Anchors to Skillet window
	if (Skillet and Skillet:IsActive()) then
		AckisRecipeListFrame:SetPoint("LEFT", SkilletFrame, "RIGHT", 0, 0)
	-- Anchor to ATSW
	elseif (ATSWFrame) then
		AckisRecipeListFrame:SetPoint("RIGHT", ATSWFrame, "RIGHT", 345, 30)
	-- Anchor to trade skill window
	elseif (ARL.SkillType == "Trade") then
		AckisRecipeListFrame:SetPoint("RIGHT", TradeSkillFrame, "RIGHT", 345, 30)
	-- Anchor to crafting window
	elseif (ARL.SkillType == "Craft") then
		AckisRecipeListFrame:SetPoint("RIGHT", CraftFrame, "RIGHT", 345, 30)
	-- Nothing found to anchor, just put it up in the middle
	else
		AckisRecipeListFrame:SetPoint("CENTER", UIParent, "CENTER", 0, 0)
	end

	-- Set the text / status bar display  of the progress bar
	if (CurrentSpeciality == "") then
		ARLProfessionText:SetText(CurrentProfession)
	else
		ARLProfessionText:SetText(CurrentProfession .. " - " .. CurrentSpeciality)
	end

	AckisRecipeListFrame:Show()

	-- Add frame elements
	ARL_AddRecipeInfo(CurrentProfession, CurrentProfessionLevel, SortedRecipeIndex, CurrentSpeciality)

	-- Include filtered recipes in overall count
	if (ARL.db.profile.includefiltered) then
		AckisRecipeListFrameProgressBar:SetMinMaxValues(0, ARL.NumberOfRecipes)
		AckisRecipeListFrameProgressBar:SetValue(ARL.FoundRecipes)
		AckisRecipeListFrameProgressBarText:SetText(ARL.FoundRecipes .. " \\ " .. ARL.NumberOfRecipes .. " - " .. math.floor(ARL.FoundRecipes / ARL.NumberOfRecipes * 100) .. "%")
	-- Do not include filtered recipes
	else
		AckisRecipeListFrameProgressBar:SetMinMaxValues(0, ARL.NumberOfRecipes - ARL.FilteredRecipes)
		AckisRecipeListFrameProgressBar:SetValue(ARL.FoundRecipes)
		AckisRecipeListFrameProgressBarText:SetText(ARL.FoundRecipes .. " \\ " .. ARL.NumberOfRecipes - ARL.FilteredRecipes .. " - " .. math.floor(ARL.FoundRecipes / (ARL.NumberOfRecipes - ARL.FilteredRecipes) * 100) .. "%")
	end

end

